import React from 'react'
import _ from 'lodash'

class BlockBase extends React.Component {
  render() {
    const inline = this.props.inline || {}
    const eventFunc = this.props.eventFunc || {}

    if (this.props.origin && inline.position !== 'absolute' ) inline.position = 'relative'

    if (this.props.mode === 'normal') {
      switch(this.props.mainAxis) {
        case 'flex-start':
          inline.textAlign = 'left'
          break;
        case 'flex-end':
          inline.textAlign = 'right'
          break;
        case 'flex-center':
          inline.textAlign = 'center'
          break;
      }
    } else {
      inline.display = 'flex'
      if (this.props.mode === 'flex-row') inline.flexDirection= 'row'
      if (this.props.mode === 'flex-column') inline.flexDirection = 'column'
      if (this.props.mainAxis) inline.justifyContent = this.props.mainAxis
      if (this.props.crossAxis) inline.alignItems = this.props.crossAxis
    }

    if (this.props.overflow) inline.overflow = this.props.overflow
    if (this.props.hidden) inline.display = 'none'

    inline.lineHeight = 1

    return (
      <div
        className={this.props.external}
        style={inline}
        { ...eventFunc }
      >
        { this.props.children }
      </div>
    )
  }
}

BlockBase.propsType = {
  mode: React.PropTypes.oneOf(['flex-row', 'flex-column', 'normal']),
  overflow: React.PropTypes.string,
  mainAxis: React.PropTypes.string,
  crossAxis: React.PropTypes.string,
  hidden: React.PropTypes.bool,
  origin: React.PropTypes.bool,
  external: React.PropTypes.string,
  inline: React.PropTypes.object,
  eventFunc: React.PropTypes.object,
}

BlockBase.defaultProps = {
  mode: 'normal',
  origin: false,
  hidden: false,
}


const Container = ({autoHeight=false, ...props}) => {
  const inline = props.inline || {}
  inline.width = '100%'
  if (!autoHeight)
    inline.height = '100%'

  return (<BlockBase inline={inline} {...props} />)
}

const Carton = ({width='auto', height='auto', fixed=false, ...props}) => {
  const inline = props.inline || {}
  inline.width = width
  inline.height = height

  if (fixed)
    inline.flex = '0 0 auto'

  return (<BlockBase inline={inline} {...props} />)
}

const Wrap = BlockBase

const Pin = ({top, bottom, left, right, index=0, width='auto', height='auto', ...props}) => {
  const inline = props.inline || {}
  if (top) inline.top = top
  if (bottom) inline.bottom = bottom
  if (left) inline.left = left
  if (right) inline.right = right

  inline.position = 'absolute'
  inline.width = width
  inline.height = height
  inline.zIndex = index

  return (<BlockBase inline={inline} {...props} />)
}

export { Container, Carton, Wrap, Pin }
